package com.pointrlabs.sample.selection

import android.content.Context
import com.pointrlabs.sample.map.MapActivity.Companion.newIntent
import androidx.appcompat.app.AppCompatActivity
import com.pointrlabs.core.site.SiteManager
import android.os.Bundle
import com.pointrlabs.sample.R
import com.pointrlabs.core.management.Pointr
import androidx.recyclerview.widget.RecyclerView
import com.pointrlabs.core.management.models.Building
import android.content.Intent
import java.util.ArrayList

/**
 * Activity to present the venue list to choose from
 */
class SelectionActivity : AppCompatActivity(), SiteManager.Listener, BuildingSelectionAdapter.Listener {

    private val adapter = BuildingSelectionAdapter(this)
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_venue_selection)

        val recyclerView = findViewById<RecyclerView>(R.id.selectionListRecyclerView)
        recyclerView.adapter = adapter

        // put building list
        onSiteManagerDataChanged()
    }

    override fun onStart() {
        super.onStart()

        val pointr = Pointr.getPointr() ?: return
        val siteManager = pointr.siteManager ?: return
        siteManager.addListener(this)
    }

    override fun onStop() {
        super.onStop()

        val pointr = Pointr.getPointr() ?: return
        val siteManager = pointr.siteManager ?: return
        siteManager.removeListener(this)
    }

    // region [SiteManager.Listener]
    override fun onSiteManagerDataChanged() {
        adapter.submitList(buildings)
    }

    // endregion [VenueFacilityManager.Listener]
    // region [BuildingSelectionAdapter.Listener
    override fun onBuildingSelected(siteInternalIdentifier: Int) {
        startActivity(newIntent(this, siteInternalIdentifier))
    }

    // endregion [BuildingSelectionAdapter.Listener]
    private val buildings: ArrayList<Building>
        get() {
            val buildings = arrayListOf<Building>()

            val pointr = Pointr.getPointr() ?: return buildings
            val siteManager = pointr.siteManager ?: return buildings

            for (site in siteManager.getSites()) {
                buildings.addAll(site.buildings)
            }
            return buildings
        }

    companion object {
        /**
         * Creates the intent to start this activity
         *
         * @return intent to start [SelectionActivity]
         */
        fun newIntent(context: Context): Intent {
            return Intent(context, SelectionActivity::class.java)
        }
    }
}